1.0.0 (2022-03-16)
------------------

* Added support for coverage>=5 for the extension-helpers test suite. [#24]

* Removed any direct usage of distutils. [#34]

* Remove support for the undocumented --compiler argument to setup.py. [#36]

* Added support for enabling extension-helpers from setup.cfg. [#33]

0.1 (2019-12-18)
----------------

* Initial release of extension-helpers, which was forked from astropy-helpers 4.0.
